#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_SUBS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_SUBS_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/scalar/subs.hpp>

#endif
